<?php

namespace Connectix;

use Connectix\Exception\NoTokenException;
use Connectix\Request;

class Client
{
	/**
	 * @var string
	 */
	private $token;

	/**
	 * @var bool
	 */
	private $isDev;

	/**
	 * @var Request\RequestInterface[]
	 */
	private $requests = [];

	/**
	 * @param string $token
	 * @param bool $isDev
	 * @throws NoTokenException
	 */
	public function __construct($token, $isDev = true)
	{
		if (empty($token)) {
			throw new NoTokenException;
		}

		$this->token = $token;
		$this->isDev = $isDev;
	}

	/**
	 * @return string
	 */
	public function getToken()
	{
		return $this->token;
	}

	/**
	 * @param string $token
	 * @return $this
	 */
	public function setToken(string $token)
	{
		$this->token = $token;
		foreach ($this->requests as $request) {
			$request->setToken($token);
		}

		return $this;
	}

	/**
	 * @return bool
	 */
	public function isDev()
	{
		return $this->isDev;
	}

	/**
	 * @param bool $isDev
	 * @return Client
	 */
	public function setIsDev(bool $isDev)
	{
		$this->isDev = $isDev;
		foreach ($this->requests as $request) {
			$request->setIsDev($isDev);
		}

		return $this;
	}

	/**
	 * @param string $name
	 * @return Request\RequestInterface|mixed
	 */
	private function getRequest(string $name)
	{
		if (!isset($this->requests[$name])) {
			$class = 'Connectix\\Request\\'.ucfirst($name).'Request';
			$this->requests[$name] = new $class($this->token, $this->isDev);
		}

		return $this->requests[$name];
	}

	/**
	 * @return Request\BlacklistRequest
	 */
	public function getBlacklist()
	{
		return $this->getRequest('blacklist');
	}

	/**
	 * @return Request\TemplatesRequest
	 */
	public function getTemplates()
	{
		return $this->getRequest('templates');
	}

	/**
	 * @return Request\MessagesRequest
	 */
	public function getMessages()
	{
		return $this->getRequest('messages');
	}

	/**
	 * @return Request\FallbackRequest
	 */
	public function getFallback()
	{
		return $this->getRequest('fallback');
	}

	/**
	 * @return Request\CountriesRequest
	 */
	public function getCountries()
	{
		return $this->getRequest('countries');
	}

	/**
	 * @return Request\IntegrationRequest
	 */
	public function getIntegration()
	{
		return $this->getRequest('integration');
	}

	/**
	 * @return Request\IntegrationHookRequest
	 */
	public function getIntegrationHook()
	{
		return $this->getRequest('integrationHook');
	}
}
